LayoutContent

Enum LayoutContent 

pub enum LayoutContent {
    None,
    Text(String),
    Field {
        value: String,
        field_kind: FieldKind,
        font_size: f64,
        font_family: FontFamily,
    },
    WrappedText {
        lines: Vec<String>,
        first_line_of_para: Vec<bool>,
        font_size: f64,
        text_align: TextAlign,
        font_family: FontFamily,
        space_above_pt: Option<f64>,
        space_below_pt: Option<f64>,
        from_field: bool,
    },
    Image {
        data: Vec<u8>,
        mime_type: String,
    },
    Draw(DrawContent),
}
Content type for layout leaf nodes.

Variants



None



Text(String)



Field

Fields

value: String
field_kind: FieldKind
font_size: f64
font_family: FontFamily


WrappedText

Pre-wrapped text lines for rendering.

Fields

lines: Vec<String>
first_line_of_para: Vec<bool>

Per-line flag: true when the line is the first line of a paragraph.

font_size: f64
text_align: TextAlign

Horizontal text alignment (from XFA <para hAlign>).

font_family: FontFamily

Font family for selecting the correct PDF font resource.

space_above_pt: Option<f64>

Additional space above the first line of text (from XFA <para spaceAbove>).

space_below_pt: Option<f64>

Additional space below the last line of text (from XFA <para spaceBelow>).

from_field: bool

True when this text originates from a field value (not a draw element).



Image

A static image.

Fields

data: Vec<u8>
mime_type: String


Draw(DrawContent)

A static draw element (line, rectangle, arc, text).