Sink

Trait Sink 

pub trait Sink {
    // Required method
    fn record(&self, event: TraceEvent);
}
Implemented by anything that wants to receive trace events.

Implementations must be cheap when called; emit sites in the engine are designed for ~one indirect call overhead when a sink is installed.

Required Methods

fn record(&self, event: TraceEvent)

Receive a single event. Implementations should not perform I/O or take locks that risk contention with engine work.

Implementors