pub struct Caption {
pub placement: CaptionPlacement,
pub reserve: Option<f64>,
pub text: String,
pub font_family: Option<String>,
pub font_size: Option<f64>,
}Expand description
A caption for a form field.
Fields
placement: CaptionPlacementCaption placement.
reserve: Option<f64>Reserved space for the caption (None = auto).
text: StringCaption text.
font_family: Option<String>Caption’s own typeface (XFA <caption><font typeface="...">). The caption
styles its label text independently of the field’s <font>; when present
it must win, otherwise an Arial caption on a Times field renders serif.
font_size: Option<f64>Caption’s own font size in points, if specified on its <font>.